// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
// Module: CalPNCoreData
// Author: Hassan Siddiqui
//
// Description: Cal PN Instrument-specific data/methods for arf generation.
// 
// Comments: 
//  
// Modifications: See ChangeLog
// 
// $Id: CalPNCoreData.cc,v 1.1.1.1 2004/02/09 14:54:12 eojero Exp $

/* General */

/* SAS-specific classes */
#include "Xmm.h"
#include "Tracer.h"

/* Local classes */
#include "CalPNCoreData.h"
#include "SimpleIterator.h"
#include "NonUnifBinnedAxis.h"
#include "NullPileupCorrector.h"

/* Constructors */

CalPNCoreData::CalPNCoreData( Xmm::Instrument instrumentID,
			      const string & datamode,
			      const string & dateobs,
			      const PosWCS * const poswcs,
			      const string & filter,
			      double psfenergy):
  CalCoreData(psfenergy, datamode, dateobs, poswcs)
{
  errstr << "Creating CalPNCoreData object .. "
         << filter
	 << Sas::message(Msg::App, Msg::Verbose);


  /* Set up CAL server */
  //calServer.setInstrument(Xmm::EPN);
  calServer.state()->ccd()->set(EPNcam::CCD_1);
  //  calServer.state()->node()->set(Xmm::PRIMARY_NODE);

 // calServer.state()->filter()->set(Xmm::toFilter(filter)); 

  /* Switch off randomization */
  //calServer.state()->randomize()->set(false);

  /* Initialise remaining members */
  init(instrumentID);
};

/*  Destructors  */
CalPNCoreData::~CalPNCoreData()
{
  PROC;
  ENDPROC;
};

unsigned CalPNCoreData::ccdFirst() const 
{ PROC; RETURN EPNcam::CCD_FIRST; }

unsigned CalPNCoreData::ccdLast()  const 
{ PROC; RETURN EPNcam::CCD_LAST;  } 


/** Iterator methods. */

GeneralIterator<int> * CalPNCoreData::xpixelIterator() const
{
  PROC;
  RETURN ( new SimpleIterator<int>( _ePNCam.minX(), 
				    _ePNCam.maxX()) );
}

GeneralIterator<int> * CalPNCoreData::ypixelIterator() const
{
  PROC;
  RETURN ( new SimpleIterator<int>( _ePNCam.minY(), 
				    _ePNCam.maxY()) );
}


