// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
// 
// Module: CalPNCoreData
// Author: Hassan Siddiqui
//
// Description: Cal PN Instrument-specific data/methods for arf generation.
// 
// Comments: 
//  
// Modifications: See ChangeLog
// 
// $Id: CalPNCoreData.h,v 1.1.1.1 2004/02/09 14:54:12 eojero Exp $

#ifndef CalPNCoreData_H
#define CalPNCoreData_H

/* General */

/* SAS-specific classes */

/* Local classes */
#include "CalCoreData.h"

class CalPNCoreData : public CalCoreData
{
public:

  /** Constructors  */
  CalPNCoreData( Xmm::Instrument instrumentID,
		 const string & datamode,
		 const string & dateobs,
		 const PosWCS * const poswcs,
		 const string & filterm,
		 double psfenergy);

  /**  Destructors  */
  ~CalPNCoreData();


  /** Iterator methods. */

  unsigned int ccdFirst() const;
  unsigned int ccdLast()  const;

  GeneralIterator<int> * xpixelIterator() const;
  GeneralIterator<int> * ypixelIterator() const;


private:

  /** Members */

  const EPNcam _ePNCam; // Contains camera layout information.
};
#endif
