// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// Module: CirclePsfModel
// Author: Richard Saxton
//
// Description: 
//
// A simple model for the PSF.
// Used for prototyping; will be eventually replaced by relevant CAL fn.
//
// Modifications: See ChangeLog
// 
// $Id: CirclePsfModel.h,v 1.1.1.1 2004/02/09 14:54:12 eojero Exp $

#ifndef CirclePsfModel_H
#define CirclePsfModel_H

/* SAS-specific */
#include "CalCommon.h"
#include "CalServer.h"
#include "EncircledEnergyDataServer.h"

/* Local */
#include "PsfModel.h"

class CirclePsfModel: public PsfModel
{
public:

  /*** NOTE: units for both x/y directions are 0.05 arcseconds ***/

  /* Constructor */
   CirclePsfModel(  double Energy,             /* Psf energy */
                    double Theta,              /* Off-axis angle */
                    double Phi,                /* Azimuthal angle */
                    vector<double> Radii,      /* Source box radii (asec) */
                    unsigned int NGridEls      /* 100 for 10*10 det map. */
                    );    

  /* Destructor */
  ~CirclePsfModel();

  /* Return normalized PSF function at given position */
  double psf( double x, 
	      double y) const;
  
  /* Calculate integrated PSF over a square area */
  double int_psf( double xboxcentre, 
		  double yboxcentre, 
		  double xboxsize,
		  double yboxsize) const;

  /* Calcluate the PSF integrated within a circle */
  double rad_psf() const;

  void energy(double energy);

  void setRadius(double Radius);

  void setNgridEls(unsigned int NGridEls);

  string mode() const;

  EncircledEnergyFunction *eef;

private:
  
  double _energy;
  double _theta;

  double _phi;
  vector<double> _radii;
  unsigned int _ngridels;

  EncircledEnergyDataServer * _eds;

  bool new_energy;

  //EncircledEnergyFunction * _eefunc = 0;
};

#endif

