// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// Module: RegionExtent
// Author: Hassan Siddiqui
//
// Description: 
//
// Class to determine the DSS region extents in
// X/Y and DETX/Y
//
// Modifications: See ChangeLog
// 
// $Id: RegionExtent.h,v 1.1.1.1 2004/02/09 14:54:12 eojero Exp $

#ifndef RegionExtent_H
#define RegionExtent_H

/* SAS */
#include "DataSubspace.h"
#include "Xmm.h"

/* Local */
#include "PositionUtils.h"
#include "PosWCS.h"

class RegionExtent
{
public:
  
  /* Construct object given explicit extent */
  RegionExtent( double xmin,
		double xmax,
		double ymin,
		double ymax );

  /* Construct object based given a DataSubspace and CoreData object */
  RegionExtent( DataSubspace * dss,
                PositionUtils * putils, const string & datamode,
                const string & dateobs, const PosWCS * const poswcs );

  /* Destructor */
  ~RegionExtent();

  /* Check if object is constructed correctly */
  bool isValid() const;

  /* Report if extent is larger than specified bounds */
  void checkBounds( double boundsxmin,
		    double boundsxmax,
		    double boundsymin,
		    double boundsymax) const;

  /* Accessors */

  double xmin() const;
  double xmax() const;
  double ymin() const;
  double ymax() const;

private:

  /* Suppress default constructor */
  RegionExtent();

  bool _isValid;

  double _xmin;
  double _xmax;
  double _ymin;
  double _ymax;
};

#endif
