// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// Module: RmfEbins
// Author: Hassan Siddiqui
//
// Description: 
//
// Factory for generating a BinnedAxis object 
// from ebins component of an rmf dataset
//
// Modifications: See ChangeLog
// 
// $Id: RmfEbins.cc,v 1.1.1.1 2004/02/09 14:54:12 eojero Exp $

/* General */

/* SAS-specific */
#include "Dal.h"
#include "Tracer.h"

/* Local */
#include "RmfEbins.h"
#include "NonUnifBinnedAxis.h"

/* Constructor */
RmfEbins::RmfEbins()
{ 
  PROC;
  ENDPROC;
}

BinnedAxis * RmfEbins::ebins( const string & setname )
{
  PROC;

  IntervalVector<double> intervalvector;

  DataSet * set = dataSetServer->open( setname, DataSet::Read );

  Table * table = 0;

  if ( set->hasBlock("MATRIX") )
    {
      table = set->table("MATRIX");
    }
  else if ( set->hasBlock("SPECRESP MATRIX") )
    {
      table = set->table("SPECRESP MATRIX");
    }
  else
    {
      errstr 
	<< "There is no table of name 'MATRIX' or 'SPECRESP MATRIX' in dataset " << setname
	<< Sas::error("NoRmfTablePresent");
    }

  Column * elowCol  = table->column("ENERG_LO");
  Column * ehighCol = table->column("ENERG_HI");

  for (unsigned row = 0; row < table->rows(); ++row)
    {
      ColumnData * elowColData  = elowCol->data(row, 1); 
      ColumnData * ehighColData = ehighCol->data(row, 1);

      Interval<double> ebins(elowColData->real32Data()[0] * 1000., 
			     ehighColData->real32Data()[0] * 1000.);
      
      intervalvector.push_back(ebins);

      delete ehighColData;
      delete elowColData;

    }

  dataSetServer->close(set);

  NonUnifBinnedAxis *nub = new NonUnifBinnedAxis(intervalvector);

  RETURN nub;
}

/* Destructor */
RmfEbins::~RmfEbins()
{
  PROC;
  ENDPROC;
}
